/* Copyright 1997 Sun Microsystems, Inc.  All rights reserved. */

/*
	spix counts file format:

	header:
		SCHdr struct
		text size and check sum of pre-spix a.out are included 
		to ensure consistency for spixstats, sdas, etc.

	basic block lengths:
		1 uint8 per block containing # instructions in block.
		large blocks must be split.  padded to 4 byte boundary.

	basic block execution counts:
		2 (adjacent) sc_t's per block:  
		for uncounted blocks (e.g. data), both counters are SC_BADCNT.
		for blocks ending bicc/fbfcc/cbccc, 1st is taken count,
		    2nd is not-taken count.
		for other blocks, 1st is execution count, 2nd is unused.
*/

#ifndef _spixcounts_h_
#define _spixcounts_h_

#pragma ident "@(#)Shade and Spixtools V5.32C, V9 SPARC SunOS"


#include <spixtypes.h>

#define SC_BADCNT	(~ (sc_t) 0)
#define SC_MAGIC	(0x62620011)


typedef uint32	sc_t;

typedef struct {
	uint32	sc_magic;	/* SC_MAGIC */
	uint32	sc_tsize;	/* size of text segment (bytes) */
	uint32	sc_tsum;	/* text segment check_sum() */
	uint32	sc_nbb;		/* # basic blocks */
} SCHdr;


#endif /*_spixcounts_h_*/
