/* Copyright 1997 Sun Microsystems, Inc.  All rights reserved. */

#ifndef trctl_h_
#define trctl_h_

#pragma ident "@(#)Shade and Spixtools V5.32C, V9 SPARC SunOS"


#include <spixtypes.h>


/*
 * tc_trace bit mask values:
 */
#define TC_I             1  /* trace instruction text */
#define TC_IH            2  /* trace opcode */
#define TC_ANNULLED      4  /* trace annulled instruction flag */
#define TC_TAKEN         8  /* trace branch/trap taken flag */
#define TC_PC           16  /* trace instruction address */
#define TC_EA           32  /* trace effective memory address */
#define TC_RS1          64  /* trace rs1 register value (before instr) */
#define TC_RS2         128  /* trace rs2 register value (before instr) */
#define TC_RD          256  /* trace rd register value (after instr) */
#define TC_FRS1        512  /* trace frs1 fp register value (before instr) */
#define TC_FRS2       1024  /* trace frs2 fp register value (before instr) */
#define TC_FRD        2048  /* trace frd fp register value (after instr) */

#define TC_STOPB     16384  /* stop before opcode */
#define TC_STOPA     32768  /* stop after opcode */

/*
 * Trace members available to tc_fun[0]:
 */
#define TC_FUN0	(TC_I|TC_IH|TC_PC|TC_EA|TC_RS1|TC_RS2|TC_FRS1|TC_FRS2)

/*
 * Trace members available to tc_fun[1]:
 */
#define TC_FUN1	(TC_FUN0|TC_TAKEN|TC_RD|TC_FRD)


#include <shade.h>
struct Trace;

#ifdef __STDC__

extern int32	shade_trctl_trsize(int);

extern uint32	shade_trctl_ih(int, int, int, uint32),
		shade_trctl_it(uint32, int, int, uint32);

typedef void	(*trfun_t)(struct Trace *, Shade *);

extern void	shade_trfun_ih(int, trfun_t, trfun_t),
		shade_trfun_it(uint32, trfun_t, trfun_t);

#else

extern int32	shade_trctl_trsize();

extern uint32	shade_trctl_ih(),
		shade_trctl_it();

typedef void	(*trfun_t)();

extern void	shade_trfun_ih(),
		shade_trfun_it();

#endif


/*
 * per-opcode trace control
 */

typedef struct {
	int8	tc_on;           /* provide any Trace info? */
	int8	tc_onannulled;   /* for annulled instructions too? */
	uint16	tc_trace;        /* trace control flags (see below) */

	/*
	 * call tc_fun[0] before simulating instruction;
	 * call tc_fun[1] after simulating instruction.
	 */
	trfun_t	tc_fun[2];
} TrCtl;

#endif	/* #ifndef trctl_h_ */
